@@ -185,8 +185,8 @@ class ClinicalQualityMeasure131v6(ExternallyAwareClinicalQualityMeasure, Diabete
                 f'{self.patient.first_name} has diabetes and a retinal examination was done '
                 f'{exam_date}, demonstrating {self._finding}.')
         else:
-            result.due_in = (self._on_date.shift(days=self.timeframe.duration * 2) - self.now).days
-            next_date = self._on_date.shift(days=self.timeframe.duration * 2).format('M/D/YY')
+            result.due_in = (self._on_date.shift(days=self.timeframe.duration) - self.now).days
+            next_date = self._on_date.shift(days=self.timeframe.duration).format('M/D/YY')
             result.add_narrative(
                 f'{self.patient.first_name} has diabetes and a retinal examination was done '
                 f'{exam_date} demonstrating no diabetic eye disease. '
@@ -208,7 +208,7 @@ class ClinicalQualityMeasure131v6(ExternallyAwareClinicalQualityMeasure, Diabete
         else:
             humanized_timeframe = ((self.now
                                     .shift(months=-1,
-                                           days=-2 * self.timeframe.duration)
+                                           days=-self.timeframe.duration)
                                     .humanize(other=self.now,
                                               granularity='month',
                                               only_distance=True))
