@@ -28,6 +28,10 @@ def green(string: str) -> str:
     return click.style(string, fg='green')
 
 
+def yellow(string: str) -> str:
+    return click.style(string, fg='yellow', bold=True)
+
+
 def red(string: str) -> str:
     return click.style(string, fg='red')
 
@@ -108,9 +112,9 @@ def load_patient(fixture_folder: Path) -> Patient:
         field = camelcase(filename.split('.')[0])
 
         with open(filepath, 'r') as file:
-            if field not in data:
-                raise click.ClickException(
-                    f'Found file that does not match a known field: "{field}"')
+            # if field not in data:
+            #     raise click.ClickException(
+            #         f'Found file that does not match a known field: "{field}"')
 
             data[field] = json.load(file)  # type: ignore
 
@@ -200,9 +204,6 @@ def create(output_path: Path):
         'authors': '"Canvas Example Medical Association (CEMA)"',
         'references': '"Gunderson, Beau;  Excellence in Software Templates. 2012 Oct 20;161(7):422-34."',
         'funding_source': '',
-        'funding_source': '',
-
-
     })
     with output_path.open('w') as output_handle:
         output_handle.write(content)
@@ -211,15 +212,22 @@ def create(output_path: Path):
 
 
 @cli.command()
-@click.argument('patient-key')
-@click.argument('output_directory', nargs=1, required=False, type=click.Path())
+@click.argument('patient-keys', nargs=-1)
+@click.option('-d', '--destination', required=False, type=click.Path(), help="Specify a directory to store the output.")
 @click.pass_context
-def fixture_from_patient(ctx, patient_key: str, output_directory: Path):
+def fixture_from_patient(ctx, patient_keys: List[str], destination: Path):
     """
-    Export a fixture for a given patient.  Providing an
-    output directory will create a json file for each key.
+    Export a fixture for the list of provided patient keys.
+    Fixtures will be created with files representing the various categories.
     Eg: billingLineItems.json, conditions.json, referralReports.json ...
     """
+
+    for patient_key in patient_keys:
+        _process_fixture_from_patient(patient_key, destination)
+
+
+@click.pass_context
+def _process_fixture_from_patient(ctx, patient_key, output_directory):
     click.echo(f'Getting fixture from patient "{patient_key}"...')
 
     response = requests.get(join(
@@ -229,13 +237,18 @@ def fixture_from_patient(ctx, patient_key: str, output_directory: Path):
     response_json = response.json()
 
     if not output_directory:
-        click.echo(response_json)
-    else:
-        output_directory = Path(output_directory)
-        output_directory.mkdir(parents=True, exist_ok=True)
-        for key, values in response_json.items():
-            (output_directory / f'{key}.json').write_text(json.dumps(values))
-        click.echo(green(f'Successfully wrote patient fixture to {output_directory.absolute()}'))
+        output_directory = Path(".")
+
+    patient = response_json['patient']
+    patient_summary = f"{patient['firstName']} {patient['lastName']} {patient['birthDate'][0:4]} ({patient['sexAtBirth']})"
+
+    output_directory = Path(output_directory) / patient_summary
+
+    output_directory.mkdir(parents=True, exist_ok=True)
+    for key, values in response_json.items():
+        (output_directory / f'{key}.json').write_text(json.dumps(values))
+
+    click.echo(green(f'Successfully wrote patient fixture to {output_directory.absolute()}'))
 
 
 @cli.command()
@@ -256,23 +269,41 @@ def test_fixture(module_path: str, fixture_folder: str, date: str = None, start_
             e.text = ''
         raise SyntaxError(f'Could not parse python file.\n  File "{module_path.absolute()}", line {e.lineno}\n    {e.text.strip()}\nSyntaxError: {e.msg}')
 
+    path = Path(fixture_folder)
+
+    subdirectories = [x for x in path.iterdir() if x.is_dir()]
+
+    if subdirectories:
+        for fixture_folder in subdirectories:
+            test_fixture_directory(fixture_folder, Class, date, start_date, end_date)
+            click.echo()
+    else:
+        test_fixture_directory(path, Class, date, start_date, end_date)
+
+
+def test_fixture_directory(fixture_folder: Path, Class: type, date: str = None, start_date: str = None, end_date: str = None):
     # 2. load JSON folder of fixture data
+    fixture_title = f"Fixture: {yellow(fixture_folder.name)}"
+
+    click.echo('-' * 80)
+    click.echo(fixture_title)
+
     patient = load_patient(Path(fixture_folder))
 
     if date:
         date = arrow.get(date)
     else:
-        date = arrow.get('2018-08-23 13:24:56')
+        date = arrow.now()
 
     if start_date:
         start_date = arrow.get(start_date)
     else:
-        start_date = arrow.get('2017-10-23 13:24:56')
+        start_date = arrow.now().shift(years=-1)
 
     if end_date:
-        start_date = arrow.get(start_date)
+        end_date = arrow.get(end_date)
     else:
-        end_date = arrow.get('2018-08-23 13:24:56')
+        end_date = arrow.now()
 
     timeframe = Timeframe(start=start_date, end=end_date)
 
@@ -282,7 +313,10 @@ def test_fixture(module_path: str, fixture_folder: str, date: str = None, start_
 
     # 4. return results
     results.recommendations = [vars(r) for r in results.recommendations]
-    click.echo(json.dumps(vars(results), indent=2))
+    if not results.recommendations:
+        click.echo(red("No recommendations"))
+    else:
+        click.echo(json.dumps(vars(results), indent=2))
 
 
 @cli.command()
