@@ -1,3 +1,5 @@
+from enum import Enum
+
 COMMAND_TYPE_IMAGING = 'imagingOrder'
 COMMAND_TYPE_IMMUNIZATION = 'immunization'
 COMMAND_TYPE_INSTRUCTION = 'instruct'
@@ -36,6 +38,9 @@ class CHANGE_TYPE:
     ALLERGY_INTOLERANCE = 'allergy_intolerance'
     "Recompute protocol on an update to allergy information."
 
+    APPOINTMENT = 'appointment'
+    "Recompute protocol when a patient's appointment is updated."
+
     BILLING_LINE_ITEM = 'billing_line_item'
     "Recompute protocol when billing line items are updated."
 
@@ -80,3 +85,15 @@ class CHANGE_TYPE:
 
     VITAL_SIGN = 'vital_sign'
     "Recompute protocol when a patient's vital signs are updated."
+
+
+class AlertPlacement(Enum):
+    ALERT_PLACEMENT_CHART = 'chart'
+    ALERT_PLACEMENT_SCHEDULING = 'scheduling'
+    ALERT_PLACEMENT_APPOINTMENT_CARD = 'appointment_card'
+    ALERT_PLACEMENT_PROFILE = 'profile'
+
+
+class AlertIntent(Enum):
+    ALERT_INTENT_NEUTRAL = 'info'
+    ALERT_INTENT_WARNING = 'warning'
