@@ -37,6 +37,8 @@ from memoization import cached
 from requests.auth import HTTPDigestAuth
 
 from . import events
+from .constants import CHANGE_TYPE
+from .metaclass import DeclarativeFieldsMetaclass
 from .patient import Patient
 from .recommendation import Recommendation, TaskRecommendation
 from .timeframe import Timeframe
@@ -146,7 +148,7 @@ class ProtocolSource(object):
         self.url = url
 
 
-class Protocol:
+class Protocol(metaclass=DeclarativeFieldsMetaclass):
 
     compute_on_change_types: List[str] = []
     responds_to_event_types: List[str] = []
@@ -169,12 +171,9 @@ class Protocol:
         """
         return cls.__name__
 
-    @classmethod
-    def protocol_title(cls) -> str:
-        return cls.title
-
     @classmethod
     def revision(cls) -> str:
+        # Dpreecated - use Class.version instead.
         raise NotImplementedError('revision must be overridden')
 
     @property
@@ -230,26 +229,38 @@ class Protocol:
         return True
 
 
+class NotificationProtocol(Protocol):
+    """
+    A protocol that sends a payload to an endpoint
+    """
+
+    def __init__(self, patient: Patient, change_types: List = None, **kwargs):
+        super().__init__(patient=patient, **kwargs)
+
+
 class ClinicalQualityMeasure(Protocol):
 
     # The data sources that will invalidate this CQM; e.g. if this CQM uses interviews then if a
     # patient interview is committed we will need to re-run this CQM
-    CHANGE_ALLERGY_INTOLERANCE = 'allergy_intolerance'
-    CHANGE_BILLING_LINE_ITEM = 'billing_line_item'
-    CHANGE_CONDITION = 'condition'
-    CHANGE_COVERAGE = 'coverage'
-    CHANGE_ENCOUNTER = 'encounter'
-    CHANGE_IMAGING_REPORT = 'imaging_report'
-    CHANGE_IMMUNIZATION = 'immunization'
-    CHANGE_INSTRUCTION = 'instruction'
-    CHANGE_INTERVIEW = 'interview'
-    CHANGE_LAB_REPORT = 'lab_report'
-    CHANGE_MEDICATION = 'medication'
-    CHANGE_PATIENT = 'patient'
-    CHANGE_PROTOCOL_OVERRIDE = 'protocol_override'
-    CHANGE_REFERRAL_REPORT = 'referral_report'
-    CHANGE_SUSPECT_HCC = 'suspect_hcc'
-    CHANGE_VITAL_SIGN = 'vital_sign'
+    #
+    # Deprecated - refer to constants.CHANGE_TYPE directly
+    CHANGE_ALLERGY_INTOLERANCE = CHANGE_TYPE.ALLERGY_INTOLERANCE
+    CHANGE_APPOINTMENT = CHANGE_TYPE.APPOINTMENT
+    CHANGE_BILLING_LINE_ITEM = CHANGE_TYPE.BILLING_LINE_ITEM
+    CHANGE_CONDITION = CHANGE_TYPE.CONDITION
+    CHANGE_COVERAGE = CHANGE_TYPE.COVERAGE
+    CHANGE_ENCOUNTER = CHANGE_TYPE.ENCOUNTER
+    CHANGE_IMAGING_REPORT = CHANGE_TYPE.IMAGING_REPORT
+    CHANGE_IMMUNIZATION = CHANGE_TYPE.IMMUNIZATION
+    CHANGE_INSTRUCTION = CHANGE_TYPE.INSTRUCTION
+    CHANGE_INTERVIEW = CHANGE_TYPE.INTERVIEW
+    CHANGE_LAB_REPORT = CHANGE_TYPE.LAB_REPORT
+    CHANGE_MEDICATION = CHANGE_TYPE.MEDICATION
+    CHANGE_PATIENT = CHANGE_TYPE.PATIENT
+    CHANGE_PROTOCOL_OVERRIDE = CHANGE_TYPE.PROTOCOL_OVERRIDE
+    CHANGE_REFERRAL_REPORT = CHANGE_TYPE.REFERRAL_REPORT
+    CHANGE_SUSPECT_HCC = CHANGE_TYPE.SUSPECT_HCC
+    CHANGE_VITAL_SIGN = CHANGE_TYPE.VITAL_SIGN
 
     data_sources: List[str] = []
 
@@ -293,6 +304,9 @@ class ClinicalQualityMeasure(Protocol):
             self.timeframe = Timeframe(start=start, end=end)
 
     def impacted_by_changes(self, change_types: Optional[List]) -> bool:
+        # TODO: See if the calling process can select and compute only the protocols
+        # that match change-types, instead of instantiating in order to check.
+        # Will help reduce code, and speed things up.
         if not change_types or not self.compute_on_change_types:
             return True
 
