@@ -1,5 +1,6 @@
 import importlib
 import inspect
+import requests
 
 from canvas_workflow_kit.protocol import ClinicalQualityMeasure
 
@@ -29,3 +30,7 @@ def parse_class_from_python_source(source):
         raise SyntaxError("More than one clinical quality measures found.")
 
     return clinical_quality_measures[0]
+
+
+def send_notification(url, payload={}, headers={}):
+    return requests.post(url, data=payload, headers=headers)
